@@ -381,6 +381,8 @@ class MeshFile(ConfigurationFile):
 
 
 class ModelConfigurationFile(ConfigurationFile):
+    """ https://ufs-weather-model.readthedocs.io/en/ufs-v1.0.0/InputsOutputs.html#modelconfigparams """
+
     name = 'model_configure'
 
     def __init__(
@@ -407,7 +409,7 @@ class ModelConfigurationFile(ConfigurationFile):
         duration_hours = round(self.duration / timedelta(hours=1))
         return '\n'.join(
             [
-                'total_member:            1',
+                f'total_member:            {len(self.sequence.models)}',
                 'print_esmf:              .true.',
                 f'namelist:                {"atm_namelist.rc" if self.create_atm_namelist_rc else "model_configure"}',
                 f'PE_MEMBER01:             {self.sequence.processors}',
